@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015,2016,2017,2018,2019,2020,2021,2022 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -37,6 +37,10 @@ bool Docs::print(int todo)
 {
    switch(todo)
    {
+      case Flags::DO_MANPAGE:
+         usage(1);
+         return 1;
+#ifndef MAKEMAN
       case Flags::DO_CHANGELOG:
          changelog();
          return 1;
@@ -61,12 +65,14 @@ bool Docs::print(int todo)
       case Flags::DO_MAKEFDEPS:
          makefdeps();
          return 1;
-      case Flags::DO_MANPAGE:
-         usage(1);
-         return 1;
       case Flags::DO_README:
          readme();
          return 1;
+#ifdef SELFREP
+      case Flags::DO_SELFREP:
+	 selfrep();
+	 return 1;
+#endif
       case Flags::DO_USAGE:
          usage(0);
          return 1;
@@ -82,6 +88,7 @@ bool Docs::print(int todo)
       case Flags::DO_VIM_HELP:
          vim_help();
          return 1;
+#endif
       default:
          return 0;
    }
@@ -95,7 +102,7 @@ void Docs::usage(bool man)
    {
       doman = 1;
       std::cout << ".\\\" DO NOT MODIFY THIS FILE! It was created by findent \\-H"                << std::endl;
-      std::cout << ".TH FINDENT \"1\" \"2022\" \"findent\\-" << VERSION << "\" \"User Commands\"" << std::endl;
+      std::cout << ".TH FINDENT \"1\" \"2023\" \"findent\\-" << VERSION << "\" \"User Commands\"" << std::endl;
       std::cout << ".SH NAME"                                                                     << std::endl;
       std::cout << "findent \\- Indents, converts and relabels Fortran programs."                 << std::endl;
       std::cout << ".SH SYNOPSIS"                                                                 << std::endl;
@@ -210,7 +217,7 @@ void Docs::usage(bool man)
    manout(" ","        findent will stop relabeling, but will continue indenting");
    manout(" ","        and/or converting.");
    manout("--relabel_reset=<n>           ","1: reset label numbering at start of subroutine/function/program.");
-   manout(" ","0: do not reset label numbering (default: 1).");
+   manout(" ","0: do not reset label numbering (default: 0).");
    manout("--query_relabel[=<n>]             ","generate report. " + no_env);
    manout(" "," n=0, or flag omitted: do not generate report.");
    manout(" "," n=1: generate summary (only error message or OK message).");
@@ -343,6 +350,22 @@ void Docs::usage(bool man)
    manout("--emacs_help                      "   ,"outputs directions to use findent in emacs. "+no_env);
    manout("--emacs_findent                   "   ,"outputs script 'findent.el', see --emacs_help. "+no_env);
    manout(" "," ");
+#ifdef SELFREP
+   if(doman)
+   {
+      std::cout << ".PP" << std::endl << ".SS \"Self replication:" << std::endl;
+   }
+   else
+   {
+      std::cout << "  Self replication:" << std::endl;
+   }
+   manout("--selfrep                         "   ,"outputs source tar ball to stdout "+no_env);
+   manout(" ","  Example: create the tar.gz file:");
+   manout(" ","     findent --selfrep > findent.tar.gz");
+   manout(" ","  Example: create the unpacked source tar ball:");
+   manout(" ","     findent --selfrep | tar zxf -");
+   manout(" "," ");
+#endif
    if(doman)
    {
       std::cout << ".PP" << std::endl << ".SS \"RELABEL:" << std::endl;
@@ -529,6 +552,7 @@ void Docs::manout(const std::string flag, const std::string txt)
    }
 }
 
+#ifndef MAKEMAN
 void Docs::vim_help()
 {
 #include "vim_help.inc"
@@ -588,3 +612,6 @@ void Docs::changelog()
 {
 #include "changelog.inc"
 }
+#endif
+
+
