@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015,2016,2017,2018,2019,2020,2021,2022 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -167,7 +167,36 @@ int Findent::run()
 	 if(flags.last_indent_only)
 	 {
 	    D(O("mycout.get");O(mycout.get()););
+	    D(O("cur_indent");O(indent->cur_indent););
 	    std::cout << num_leading_spaces(mycout.get()) << endline;
+	    /*
+	       std::string s;
+	       switch(input_format)
+	       {
+	       case FIXED:
+	       s = mycout.get();
+	       if (s.length() <= 6)
+	       std::cout << 0 << std::endl;
+	       else
+	    // skip over label and continuation character
+	    std::cout << 6 + num_leading_spaces(s.substr(6));
+	    break;
+	    default:
+	    std::cout << num_leading_spaces(mycout.get()) << endline;
+	    break;
+	    }
+	    */
+	    /*
+	       switch (input_format)
+	       {
+	       case FIXED:
+	       std::cout << 6 + indent->cur_indent << endline;
+	       break;
+	       default:
+	       std::cout << indent->cur_indent << endline;
+	       break;
+	       }
+	       */
 	 }
 	 if(flags.deps)
 	    output_deps();
