@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015,2016,2017,2018,2019,2020,2021,2022 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -71,11 +71,12 @@ void Flags::set_defaults(void)
    query_relabel        = 0;
    refactor_end         = 0;
    relabel              = 0;
-   relabel_reset        = 1;
+   relabel_reset        = 0;
    relabel_start        = RELABEL_START;
    relabel_increment    = RELABEL_INCREMENT;
    return_format        = 0;
    safe                 = 0;
+   selfrep              = 0;
    start_indent         = 0;
    upcase_end_type      = 0;
    ws_remred            = 0;
@@ -314,6 +315,8 @@ int Flags::get_flags(int argc, char *argv[])
 
       {"deps"               , no_argument,       0, DO_DEPS              },
 
+      {"selfrep"            , no_argument,       0, DO_SELFREP           },
+
       {"end_of_env"         , no_argument,       0, DO_END_ENV           },
 
       {0,0,0,0}
@@ -540,6 +543,7 @@ int Flags::get_flags(int argc, char *argv[])
 	    if(end_env_found)
 	       deps = 1;
 	    break;
+
 	 case DO_INCLUDE_LEFT:
 	    optargcheck;
 	    include_left       = (atoi(optarg) != 0);     // --include_left=0/1
@@ -678,6 +682,7 @@ int Flags::get_flags(int argc, char *argv[])
 	 case DO_GEDIT_PLUGIN_PY:
 	 case DO_MAKEFDEPS:
 	 case DO_README:
+	 case DO_SELFREP:
 	 case DO_VIM_FINDENT:
 	 case DO_VIM_FORTRAN:
 	 case DO_VIM_HELP:
