@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015,2016,2017,2018,2019,2020,2021,2022 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -164,9 +164,32 @@ int Fortran::guess_indent(Fortranline line)
    if (line.format() == FIXED)
    {
       std::string s = line.str();
-      si             = s.find_first_not_of(' ') -6;
-      if (si <0)
+      if (s.length() <= 6)
+	 return 0;
+      /*
+	 t = s.find_first_not_of(' ',6);
+	 if (t != std::string::npos)
+	 si = t;
+	 else
 	 si = 0;
+	 */
+      for (unsigned int j=6; j<s.length(); j++)
+      {
+	 switch (s[j])
+	 {
+	    case ' ':
+	       si++;
+	       break;
+	    case '\t':
+	       si = (si/tabl)*tabl + tabl;
+	       break;
+	    default:
+	       ready = 1;
+	       break;
+	 }
+	 if(ready)
+	    break;
+      }
       return si;
    }
 
@@ -400,16 +423,27 @@ void Fortran::get_full_statement()
 
 	 case in_fortran:
 	    if(End_of_file) { state = end_fortran; break; }
+	    // issue14
+	    // Always check if we are dealing with a preprocessor line: 
+	    pregentype = Curline.getpregentype();
+	    if(pregentype == CPP || pregentype == COCO)
+	    {
+	       state = in_pre;
+	       break;
+	    }
+	    // /issue14
 
 	    Curline.preregion(pregion);
 	    build_statement(Curline, f_more, pushback);
-	    D(O("Full_statement ");O(Curline.str());O(f_more);O(pushback););
+	    D(O("issue14 Curline ");O(Curline.str());O(f_more);O(pushback););
+	    D(O("issue14 Full_statement ");O(full_statement););
 
 	    if (f_more)
 	    {
 	       Curline = Getnext(End_of_file); 
 	       if (End_of_file) { state = end_fortran; break; }
 	       pregentype = Curline.getpregentype();
+	       D(O("issue14");O(Curline.str());O(pregentype==CPP);O(pregentype==COCO););
 	       if (pregentype == CPP || pregentype == COCO)
 	       {
 		  p_more = 0;
@@ -638,6 +672,13 @@ void Fortran::indent_and_output()
 {
    std::string rest = full_statement;
    bool first_time  = 1;
+
+   // first_code_line is used to prevent popping up the previous
+   // indent when encountering and END, ENDIF,... as the first
+   // non blank line. The effect is especially noticeable when
+   // using findent in vim.
+   //
+   static bool first_code_line = 1;
    while(1)
    {
       Line_prep p(rest);
@@ -655,7 +696,6 @@ void Fortran::indent_and_output()
 	    pop_indent();
 	    pop_dolabel();
 	    Cur_indent = top_indent();
-	    //fi->indent_handled = 1;
 	    indent_handled = 1;
 	 }
       }
@@ -798,7 +838,7 @@ void Fortran::indent_and_output()
 	    case ENDSUBMODULE:
 	    case ENDINTERFACE:
 	    case ENDTYPE:
-	       if (!indent_handled)
+	       if (!indent_handled && !first_code_line)
 		  Cur_indent = pop_indent();
 	       cur_rprop = top_rprops();
 	       pop_rprops();
@@ -815,15 +855,15 @@ void Fortran::indent_and_output()
 	    case ENDTEAM:
 	    case ENDWHERE:
 	       D(O("indent_handled:");O(indent_handled););
-	       if (!indent_handled)
+	       if (!indent_handled && !first_code_line)
 		  Cur_indent = pop_indent();
 	       break;
 	    case PROCEDURE:  // in fact: moduleprocedure
-			     //
-			     // depending on what follows this will be 
-			     // recognized as a module procedure with content
-			     // or only a moduleprocedure specification
-			     //
+	       //
+	       // depending on what follows this will be 
+	       // recognized as a module procedure with content
+	       // or only a moduleprocedure specification
+	       //
 	       break;
 	    case CONTAINS:
 	       if (FLAGS.indent_contain)
@@ -883,12 +923,15 @@ void Fortran::indent_and_output()
 	    default:
 	       Cur_indent = top_indent();
 	 } // end determine indent and refactor
+	 D(O("Cur_indent");O(Cur_indent));
+
 
 	 switch(props.kind)
 	 {
 	    case BLANK:
 	       break;
 	    default:
+	       first_code_line = 0;
 	       prev_props = props;
 	 }
 	 if(first_time)  // check to handle multi-statement line like x=1;y=3
