@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015,2016,2017,2018,2019,2020,2021,2022 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -251,9 +251,9 @@ void Fortran::do_relabel()
 	 propstruct  labs;
 
 	 int first_line, last_line;
-	 first_line = 10000000;
-	 last_line  = 0;
-	 int pregion;
+	 first_line  = 10000000;
+	 last_line   = 0;
+	 int pregion = 0;
 
 
 	 switch(state)
